# FireFighter

[![PyPI - Version](https://img.shields.io/pypi/v/firefighter-incident)](https://pypi.org/project/firefighter-incident/) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/firefighter-incident)](https://pypi.org/project/firefighter-incident/) [![PyPI - License](https://img.shields.io/pypi/l/firefighter-incident)](https://manomanotech.github.io/firefighter-incident/latest/license/) [![OpenSSF Best Practices](https://www.bestpractices.dev/projects/8170/badge)](https://www.bestpractices.dev/projects/8170) [![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit)](https://github.com/pre-commit/pre-commit) [![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

FireFighter is ManoMano's in-house Incident Management Tool.

It helps manage incidents, by automatically creating a Slack channel for communication, integrating with Jira (with P1-P5 priority mapping), and much more.

![Slack Bot Commands](docs/assets/screenshots/slack_bot_home.jpeg)

__What's Incident Management?__

Incident Management is a set of processes and tools to help teams detect, respond to, and resolve incidents quickly and effectively.

Incidents are unplanned interruptions or reductions in quality of services, like a service outage or a security breach.

<!--intro-end-->

## Learn more

Check out our [documentation](https://manomanotech.github.io/firefighter-incident/latest/) for more details.

## Contributing

See [our Contribution Guide](https://manomanotech.github.io/firefighter-incident/latest/contributing/) for details on submitting patches, the contribution workflow and developer's guide.

## License

FireFighter is under the MIT license. See the [LICENSE](LICENSE) file for details.
